Package com.growsurf.api.client
Interface GrowsurfClient.WithRawResponse
-
- All Implemented Interfaces:
public interface GrowsurfClient.WithRawResponseA view of GrowsurfClient that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract GrowsurfClient.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract AccountService.WithRawResponseaccount()abstract TeamService.WithRawResponseteam()abstract CampaignService.WithRawResponsecampaign()-
-
Method Detail
-
withOptions
abstract GrowsurfClient.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
account
abstract AccountService.WithRawResponse account()
-
team
abstract TeamService.WithRawResponse team()
-
campaign
abstract CampaignService.WithRawResponse campaign()
-
-
-
-