Class CreateAccountResponse
-
- All Implemented Interfaces:
public final class CreateAccountResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCreateAccountResponse.BuilderA builder for CreateAccountResponse.
public final classCreateAccountResponse.VerificationStatusGrowSurf-team verification state.
-
Method Summary
Modifier and Type Method Description final StringapiKey()An API key for the new account. final Stringemail()final CreateAccountResponse.VerificationStatusverificationStatus()final JsonField<String>_apiKey()Returns the raw JSON value of apiKey. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<CreateAccountResponse.VerificationStatus>_verificationStatus()Returns the raw JSON value of verificationStatus. final Map<String, JsonValue>_additionalProperties()final CreateAccountResponse.BuildertoBuilder()final CreateAccountResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CreateAccountResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CreateAccountResponse. -
-
Method Detail
-
apiKey
final String apiKey()
An API key for the new account. Use it as the
Bearertoken on subsequent requests. Locked (403EMAIL_NOT_VERIFIED_ERROR) until the account's email is verified, and rotated when the account owner first signs in to the GrowSurf dashboard.
-
verificationStatus
final CreateAccountResponse.VerificationStatus verificationStatus()
-
_apiKey
final JsonField<String> _apiKey()
Returns the raw JSON value of apiKey.
Unlike apiKey, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_verificationStatus
final JsonField<CreateAccountResponse.VerificationStatus> _verificationStatus()
Returns the raw JSON value of verificationStatus.
Unlike verificationStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CreateAccountResponse.Builder toBuilder()
-
validate
final CreateAccountResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CreateAccountResponse.Builder builder()
Returns a mutable builder for constructing an instance of CreateAccountResponse.
The following fields are required:
.apiKey() .email() .verificationStatus()
-
-
-
-