Class CampaignRetrieveAnalyticsResponse
-
- All Implemented Interfaces:
public final class CampaignRetrieveAnalyticsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCampaignRetrieveAnalyticsResponse.BuilderA builder for CampaignRetrieveAnalyticsResponse.
public final classCampaignRetrieveAnalyticsResponse.Analyticspublic final classCampaignRetrieveAnalyticsResponse.Seriespublic final classCampaignRetrieveAnalyticsResponse.PreviousPeriodTotals for the equal-length window immediately preceding the requested one.
public final classCampaignRetrieveAnalyticsResponse.RatesDerived referral rates, each a ratio in the range 0–1 (0 when its denominator is 0).
public final classCampaignRetrieveAnalyticsResponse.StatusCountsStatus-count breakdowns.
rewardStatusis present for every program;affiliateStatus,commissionStatus, andpayoutStatusare present only for affiliate programs. Money amounts are in minor units ofcurrencyISO.
-
Method Summary
-
-
Method Detail
-
analytics
final CampaignRetrieveAnalyticsResponse.Analytics analytics()
-
previousPeriod
final Optional<CampaignRetrieveAnalyticsResponse.PreviousPeriod> previousPeriod()
Present only when
includecontainspreviousPeriod.
-
rates
final Optional<CampaignRetrieveAnalyticsResponse.Rates> rates()
Present only when
includecontainsrates.
-
series
final Optional<List<CampaignRetrieveAnalyticsResponse.Series>> series()
Present only when
intervalisday,week, ormonth. Per-period totals, ascending.
-
statusCounts
final Optional<CampaignRetrieveAnalyticsResponse.StatusCounts> statusCounts()
Present only when
includecontainsstatusCounts.
-
_analytics
final JsonField<CampaignRetrieveAnalyticsResponse.Analytics> _analytics()
Returns the raw JSON value of analytics.
Unlike analytics, this method doesn't throw if the JSON field has an unexpected type.
-
_endDate
final JsonField<Long> _endDate()
Returns the raw JSON value of endDate.
Unlike endDate, this method doesn't throw if the JSON field has an unexpected type.
-
_previousPeriod
final JsonField<CampaignRetrieveAnalyticsResponse.PreviousPeriod> _previousPeriod()
Returns the raw JSON value of previousPeriod.
Unlike previousPeriod, this method doesn't throw if the JSON field has an unexpected type.
-
_rates
final JsonField<CampaignRetrieveAnalyticsResponse.Rates> _rates()
Returns the raw JSON value of rates.
Unlike rates, this method doesn't throw if the JSON field has an unexpected type.
-
_series
final JsonField<List<CampaignRetrieveAnalyticsResponse.Series>> _series()
Returns the raw JSON value of series.
Unlike series, this method doesn't throw if the JSON field has an unexpected type.
-
_startDate
final JsonField<Long> _startDate()
Returns the raw JSON value of startDate.
Unlike startDate, this method doesn't throw if the JSON field has an unexpected type.
-
_statusCounts
final JsonField<CampaignRetrieveAnalyticsResponse.StatusCounts> _statusCounts()
Returns the raw JSON value of statusCounts.
Unlike statusCounts, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CampaignRetrieveAnalyticsResponse.Builder toBuilder()
-
validate
final CampaignRetrieveAnalyticsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CampaignRetrieveAnalyticsResponse.Builder builder()
Returns a mutable builder for constructing an instance of CampaignRetrieveAnalyticsResponse.
The following fields are required:
.analytics() .endDate() .startDate()
-
-
-
-