Package com.growsurf.api.models.campaign
Class CampaignRetrieveAnalyticsResponse.Rates
-
- All Implemented Interfaces:
public final class CampaignRetrieveAnalyticsResponse.RatesDerived referral rates, each a ratio in the range 0–1 (0 when its denominator is 0).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCampaignRetrieveAnalyticsResponse.Rates.BuilderA builder for Rates.
-
Method Summary
-
-
Method Detail
-
participationRate
final Optional<Double> participationRate()
participantsdivided byuniqueImpressions.
-
referralConversionRate
final Optional<Double> referralConversionRate()
referralsdivided byuniqueImpressions.
-
sharesPerParticipant
final Optional<Double> sharesPerParticipant()
Total shares across all channels divided by
participants.
-
_participationRate
final JsonField<Double> _participationRate()
Returns the raw JSON value of participationRate.
Unlike participationRate, this method doesn't throw if the JSON field has an unexpected type.
-
_referralConversionRate
final JsonField<Double> _referralConversionRate()
Returns the raw JSON value of referralConversionRate.
Unlike referralConversionRate, this method doesn't throw if the JSON field has an unexpected type.
-
_sharesPerParticipant
final JsonField<Double> _sharesPerParticipant()
Returns the raw JSON value of sharesPerParticipant.
Unlike sharesPerParticipant, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CampaignRetrieveAnalyticsResponse.Rates.Builder toBuilder()
-
validate
final CampaignRetrieveAnalyticsResponse.Rates validate()
-
builder
final static CampaignRetrieveAnalyticsResponse.Rates.Builder builder()
Returns a mutable builder for constructing an instance of Rates.
-
-
-
-