Class DeleteWebhookResponse
-
- All Implemented Interfaces:
public final class DeleteWebhookResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeleteWebhookResponse.BuilderA builder for DeleteWebhookResponse.
-
Method Summary
Modifier and Type Method Description final Stringid()The deleted webhook id. final Booleansuccess()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final DeleteWebhookResponse.BuildertoBuilder()final DeleteWebhookResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeleteWebhookResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DeleteWebhookResponse. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeleteWebhookResponse.Builder toBuilder()
-
validate
final DeleteWebhookResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DeleteWebhookResponse.Builder builder()
Returns a mutable builder for constructing an instance of DeleteWebhookResponse.
The following fields are required:
.id() .success()
-
-
-
-