Class WebhookCreateParams
-
- All Implemented Interfaces:
-
com.growsurf.api.core.Params
public final class WebhookCreateParams implements Params
Adds a webhook to the program.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookCreateParams.BuilderA builder for WebhookCreateParams.
public final classWebhookCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final StringpayloadUrl()The URL that receives webhook deliveries. final Optional<List<WebhookEvent>>events()The events this webhook is subscribed to. final Optional<Boolean>isEnabled()final Optional<String>secret()Write-only. final JsonField<String>_payloadUrl()Returns the raw JSON value of payloadUrl. final JsonField<List<WebhookEvent>>_events()Returns the raw JSON value of events. final JsonField<Boolean>_isEnabled()Returns the raw JSON value of isEnabled. final JsonField<String>_secret()Returns the raw JSON value of secret. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final WebhookCreateParams.BuildertoBuilder()final WebhookCreateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of WebhookCreateParams. -
-
Method Detail
-
payloadUrl
final String payloadUrl()
The URL that receives webhook deliveries.
-
events
final Optional<List<WebhookEvent>> events()
The events this webhook is subscribed to. When omitted, the webhook is subscribed to no events.
-
secret
final Optional<String> secret()
Write-only. Used to sign deliveries (the
GrowSurf-SignatureHMAC header). Never returned.
-
_payloadUrl
final JsonField<String> _payloadUrl()
Returns the raw JSON value of payloadUrl.
Unlike payloadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_events
final JsonField<List<WebhookEvent>> _events()
Returns the raw JSON value of events.
Unlike events, this method doesn't throw if the JSON field has an unexpected type.
-
_isEnabled
final JsonField<Boolean> _isEnabled()
Returns the raw JSON value of isEnabled.
Unlike isEnabled, this method doesn't throw if the JSON field has an unexpected type.
-
_secret
final JsonField<String> _secret()
Returns the raw JSON value of secret.
Unlike secret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final WebhookCreateParams.Builder toBuilder()
-
_body
final WebhookCreateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static WebhookCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of WebhookCreateParams.
The following fields are required:
.payloadUrl()
-
-
-
-