Class WebhookCreateParams.Body
-
- All Implemented Interfaces:
public final class WebhookCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringpayloadUrl()The URL that receives webhook deliveries. final Optional<List<WebhookEvent>>events()The events this webhook is subscribed to. final Optional<Boolean>isEnabled()final Optional<String>secret()Write-only. final JsonField<String>_payloadUrl()Returns the raw JSON value of payloadUrl. final JsonField<List<WebhookEvent>>_events()Returns the raw JSON value of events. final JsonField<Boolean>_isEnabled()Returns the raw JSON value of isEnabled. final JsonField<String>_secret()Returns the raw JSON value of secret. final Map<String, JsonValue>_additionalProperties()final WebhookCreateParams.Body.BuildertoBuilder()final WebhookCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
payloadUrl
final String payloadUrl()
The URL that receives webhook deliveries.
-
events
final Optional<List<WebhookEvent>> events()
The events this webhook is subscribed to. When omitted, the webhook is subscribed to no events.
-
secret
final Optional<String> secret()
Write-only. Used to sign deliveries (the
GrowSurf-SignatureHMAC header). Never returned.
-
_payloadUrl
final JsonField<String> _payloadUrl()
Returns the raw JSON value of payloadUrl.
Unlike payloadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_events
final JsonField<List<WebhookEvent>> _events()
Returns the raw JSON value of events.
Unlike events, this method doesn't throw if the JSON field has an unexpected type.
-
_isEnabled
final JsonField<Boolean> _isEnabled()
Returns the raw JSON value of isEnabled.
Unlike isEnabled, this method doesn't throw if the JSON field has an unexpected type.
-
_secret
final JsonField<String> _secret()
Returns the raw JSON value of secret.
Unlike secret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookCreateParams.Body.Builder toBuilder()
-
validate
final WebhookCreateParams.Body validate()
-
builder
final static WebhookCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.payloadUrl()
-
-
-
-