Enum WebhookEvent.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum WebhookEvent.Known extends Enum<WebhookEvent.Known>
An enum containing WebhookEvent's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<WebhookEvent.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PARTICIPANT_REACHED_A_GOALNEW_PARTICIPANT_ADDEDCAMPAIGN_ENDEDPARTICIPANT_FRAUD_STATUS_UPDATEDNEW_COMMISSION_ADDEDCOMMISSION_ADJUSTEDNEW_PAYOUT_ISSUED
-
Method Summary
Modifier and Type Method Description final WebhookEvent.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<WebhookEvent.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<WebhookEvent.Known>getEntries()An enum containing WebhookEvent's known values. -
-
Method Detail
-
valueOf
final WebhookEvent.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<WebhookEvent.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<WebhookEvent.Known> getEntries()
An enum containing WebhookEvent's known values.
-
-
-
-