Class WebhookListResponse
-
- All Implemented Interfaces:
public final class WebhookListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookListResponse.BuilderA builder for WebhookListResponse.
-
Method Summary
Modifier and Type Method Description final List<Webhook>webhooks()final JsonField<List<Webhook>>_webhooks()Returns the raw JSON value of webhooks. final Map<String, JsonValue>_additionalProperties()final WebhookListResponse.BuildertoBuilder()final WebhookListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of WebhookListResponse. -
-
Method Detail
-
_webhooks
final JsonField<List<Webhook>> _webhooks()
Returns the raw JSON value of webhooks.
Unlike webhooks, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookListResponse.Builder toBuilder()
-
validate
final WebhookListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookListResponse.Builder builder()
Returns a mutable builder for constructing an instance of WebhookListResponse.
The following fields are required:
.webhooks()
-
-
-
-