Class WebhookTestParams
-
- All Implemented Interfaces:
-
com.growsurf.api.core.Params
public final class WebhookTestParams implements Params
Sends a live test event to a webhook using its stored URL and secret.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookTestParams.BuilderA builder for WebhookTestParams.
public final classWebhookTestParams.Body
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<String>webhookId()final Optional<WebhookEvent>event()The event to simulate. final JsonField<WebhookEvent>_event()Returns the raw JSON value of event. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final WebhookTestParams.BuildertoBuilder()final WebhookTestParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookTestParams.Builderbuilder()Returns a mutable builder for constructing an instance of WebhookTestParams. -
-
Method Detail
-
event
final Optional<WebhookEvent> event()
The event to simulate. When omitted, the webhook's first enabled event is used (
400if the webhook has no enabled events).
-
_event
final JsonField<WebhookEvent> _event()
Returns the raw JSON value of event.
Unlike event, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final WebhookTestParams.Builder toBuilder()
-
_body
final WebhookTestParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static WebhookTestParams.Builder builder()
Returns a mutable builder for constructing an instance of WebhookTestParams.
The following fields are required:
.id() .webhookId()
-
-
-
-