Class WebhookTestResponse
-
- All Implemented Interfaces:
public final class WebhookTestResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookTestResponse.BuilderA builder for WebhookTestResponse.
public final classWebhookTestResponse.PayloadThe mock event payload that was sent.
public final classWebhookTestResponse.Response
-
Method Summary
Modifier and Type Method Description final Optional<WebhookTestResponse.Payload>payload()The mock event payload that was sent. final Optional<WebhookTestResponse.Response>response()final Booleansuccess()final JsonField<WebhookTestResponse.Payload>_payload()Returns the raw JSON value of payload. final JsonField<WebhookTestResponse.Response>_response()Returns the raw JSON value of response. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final WebhookTestResponse.BuildertoBuilder()final WebhookTestResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookTestResponse.Builderbuilder()Returns a mutable builder for constructing an instance of WebhookTestResponse. -
-
Method Detail
-
payload
final Optional<WebhookTestResponse.Payload> payload()
The mock event payload that was sent.
-
response
final Optional<WebhookTestResponse.Response> response()
-
_payload
final JsonField<WebhookTestResponse.Payload> _payload()
Returns the raw JSON value of payload.
Unlike payload, this method doesn't throw if the JSON field has an unexpected type.
-
_response
final JsonField<WebhookTestResponse.Response> _response()
Returns the raw JSON value of response.
Unlike response, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookTestResponse.Builder toBuilder()
-
validate
final WebhookTestResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookTestResponse.Builder builder()
Returns a mutable builder for constructing an instance of WebhookTestResponse.
The following fields are required:
.success()
-
-
-
-