Class WebhookTestResponse.Response
-
- All Implemented Interfaces:
public final class WebhookTestResponse.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookTestResponse.Response.BuilderA builder for Response.
-
Method Summary
Modifier and Type Method Description final Optional<String>msg()final Optional<Long>statusCode()final JsonField<String>_msg()Returns the raw JSON value of msg. final JsonField<Long>_statusCode()Returns the raw JSON value of statusCode. final Map<String, JsonValue>_additionalProperties()final WebhookTestResponse.Response.BuildertoBuilder()final WebhookTestResponse.Responsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookTestResponse.Response.Builderbuilder()Returns a mutable builder for constructing an instance of Response. -
-
Method Detail
-
statusCode
final Optional<Long> statusCode()
-
_msg
final JsonField<String> _msg()
Returns the raw JSON value of msg.
Unlike msg, this method doesn't throw if the JSON field has an unexpected type.
-
_statusCode
final JsonField<Long> _statusCode()
Returns the raw JSON value of statusCode.
Unlike statusCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookTestResponse.Response.Builder toBuilder()
-
validate
final WebhookTestResponse.Response validate()
-
builder
final static WebhookTestResponse.Response.Builder builder()
Returns a mutable builder for constructing an instance of Response.
-
-
-
-