Package com.growsurf.api.models.team
Class RotateApiKeyResponse
-
- All Implemented Interfaces:
public final class RotateApiKeyResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRotateApiKeyResponse.BuilderA builder for RotateApiKeyResponse.
-
Method Summary
Modifier and Type Method Description final StringapiKey()The new API key. final JsonField<String>_apiKey()Returns the raw JSON value of apiKey. final Map<String, JsonValue>_additionalProperties()final RotateApiKeyResponse.BuildertoBuilder()final RotateApiKeyResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RotateApiKeyResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RotateApiKeyResponse. -
-
Method Detail
-
apiKey
final String apiKey()
The new API key. Store it now; the key used for rotation stops working immediately.
-
_apiKey
final JsonField<String> _apiKey()
Returns the raw JSON value of apiKey.
Unlike apiKey, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RotateApiKeyResponse.Builder toBuilder()
-
validate
final RotateApiKeyResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RotateApiKeyResponse.Builder builder()
Returns a mutable builder for constructing an instance of RotateApiKeyResponse.
The following fields are required:
.apiKey()
-
-
-
-