Package com.growsurf.api.models.team
Class VerificationEmailResponse
-
- All Implemented Interfaces:
public final class VerificationEmailResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVerificationEmailResponse.BuilderA builder for VerificationEmailResponse.
public final classVerificationEmailResponse.Status
-
Method Summary
Modifier and Type Method Description final VerificationEmailResponse.Statusstatus()final Booleansuccess()final JsonField<VerificationEmailResponse.Status>_status()Returns the raw JSON value of status. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final VerificationEmailResponse.BuildertoBuilder()final VerificationEmailResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VerificationEmailResponse.Builderbuilder()Returns a mutable builder for constructing an instance of VerificationEmailResponse. -
-
Method Detail
-
status
final VerificationEmailResponse.Status status()
-
_status
final JsonField<VerificationEmailResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VerificationEmailResponse.Builder toBuilder()
-
validate
final VerificationEmailResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VerificationEmailResponse.Builder builder()
Returns a mutable builder for constructing an instance of VerificationEmailResponse.
The following fields are required:
.status() .success()
-
-
-
-