Package com.growsurf.api.services.async
Class AccountServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.async.AccountServiceAsync.WithRawResponse
public final class AccountServiceAsyncImpl.WithRawResponseImpl implements AccountServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccountServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CreateAccountResponse>>create(AccountCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Account>>retrieve(AccountRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Account>>update(AccountUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RotateApiKeyResponse>>rotateApiKey(AccountRotateApiKeyParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Account>>requestVerification(AccountRequestVerificationParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<VerificationEmailResponse>>resendVerificationEmail(AccountResendVerificationEmailParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.async.AccountServiceAsync.WithRawResponse
create, requestVerification, requestVerification, requestVerification, resendVerificationEmail, resendVerificationEmail, resendVerificationEmail, retrieve, retrieve, retrieve, rotateApiKey, rotateApiKey, rotateApiKey, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AccountServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CreateAccountResponse>> create(AccountCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<Account>> retrieve(AccountRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<Account>> update(AccountUpdateParams params, RequestOptions requestOptions)
-
rotateApiKey
CompletableFuture<HttpResponseFor<RotateApiKeyResponse>> rotateApiKey(AccountRotateApiKeyParams params, RequestOptions requestOptions)
-
requestVerification
CompletableFuture<HttpResponseFor<Account>> requestVerification(AccountRequestVerificationParams params, RequestOptions requestOptions)
-
resendVerificationEmail
CompletableFuture<HttpResponseFor<VerificationEmailResponse>> resendVerificationEmail(AccountResendVerificationEmailParams params, RequestOptions requestOptions)
-
-
-
-