Class DesignServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.async.campaign.DesignServiceAsync
public final class DesignServiceAsyncImpl implements DesignServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDesignServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DesignServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DesignServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CampaignDesign>retrieve(DesignRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CampaignDesign>update(DesignUpdateParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.async.campaign.DesignServiceAsync
retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
DesignServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DesignServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<CampaignDesign> retrieve(DesignRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CampaignDesign> update(DesignUpdateParams params, RequestOptions requestOptions)
-
-
-
-