Class InstallationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.async.campaign.InstallationServiceAsync
public final class InstallationServiceAsyncImpl implements InstallationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstallationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InstallationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InstallationServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CampaignInstallation>retrieve(InstallationRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CampaignInstallation>update(InstallationUpdateParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.async.campaign.InstallationServiceAsync
retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InstallationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InstallationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<CampaignInstallation> retrieve(InstallationRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CampaignInstallation> update(InstallationUpdateParams params, RequestOptions requestOptions)
-
-
-
-