Class OptionsServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.async.campaign.OptionsServiceAsync
public final class OptionsServiceAsyncImpl implements OptionsServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOptionsServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OptionsServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OptionsServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CampaignOptions>retrieve(OptionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CampaignOptions>update(OptionUpdateParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.async.campaign.OptionsServiceAsync
retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
OptionsServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
OptionsServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<CampaignOptions> retrieve(OptionRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CampaignOptions> update(OptionUpdateParams params, RequestOptions requestOptions)
-
-
-
-