Class OptionsServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.async.campaign.OptionsServiceAsync.WithRawResponse
public final class OptionsServiceAsyncImpl.WithRawResponseImpl implements OptionsServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description OptionsServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CampaignOptions>>retrieve(OptionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CampaignOptions>>update(OptionUpdateParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.async.campaign.OptionsServiceAsync.WithRawResponse
retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
OptionsServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<CampaignOptions>> retrieve(OptionRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<CampaignOptions>> update(OptionUpdateParams params, RequestOptions requestOptions)
-
-
-
-