Class RewardsServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.async.campaign.RewardsServiceAsync
public final class RewardsServiceAsyncImpl implements RewardsServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRewardsServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RewardsServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RewardsServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Reward>create(RewardCreateParams params, RequestOptions requestOptions)CompletableFuture<Reward>update(RewardUpdateParams params, RequestOptions requestOptions)CompletableFuture<CampaignRewardListResponse>list(RewardListParams params, RequestOptions requestOptions)CompletableFuture<DeleteRewardResponse>delete(RewardDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.async.campaign.RewardsServiceAsync
create, create, create, delete, delete, delete, list, list, list, list, list, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
RewardsServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RewardsServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Reward> create(RewardCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Reward> update(RewardUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CampaignRewardListResponse> list(RewardListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<DeleteRewardResponse> delete(RewardDeleteParams params, RequestOptions requestOptions)
-
-
-
-