Interface WebhooksServiceAsync
-
- All Implemented Interfaces:
public interface WebhooksServiceAsyncProgram webhook configuration (create, update, delete, and test webhooks).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWebhooksServiceAsync.WithRawResponseA view of WebhooksServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract WebhooksServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WebhooksServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Webhook> create(String id, WebhookCreateParams params)
Adds a webhook to the program.
-
create
CompletableFuture<Webhook> create(String id, WebhookCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<Webhook> create(WebhookCreateParams params)
-
create
abstract CompletableFuture<Webhook> create(WebhookCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Webhook> update(String webhookId, WebhookUpdateParams params)
Updates a webhook by id.
-
update
CompletableFuture<Webhook> update(String webhookId, WebhookUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Webhook> update(WebhookUpdateParams params)
-
update
abstract CompletableFuture<Webhook> update(WebhookUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<WebhookListResponse> list(String id)
Lists a program's webhooks (secrets are never returned).
-
list
CompletableFuture<WebhookListResponse> list(String id, WebhookListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<WebhookListResponse> list(String id, WebhookListParams params)
-
list
abstract CompletableFuture<WebhookListResponse> list(WebhookListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<WebhookListResponse> list(WebhookListParams params)
-
list
CompletableFuture<WebhookListResponse> list(String id, RequestOptions requestOptions)
-
delete
CompletableFuture<DeleteWebhookResponse> delete(String webhookId, WebhookDeleteParams params)
Removes a webhook by id.
-
delete
CompletableFuture<DeleteWebhookResponse> delete(String webhookId, WebhookDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<DeleteWebhookResponse> delete(WebhookDeleteParams params)
-
delete
abstract CompletableFuture<DeleteWebhookResponse> delete(WebhookDeleteParams params, RequestOptions requestOptions)
-
test
CompletableFuture<WebhookTestResponse> test(String webhookId, WebhookTestParams params)
Sends a live test event to a webhook using its stored URL and secret.
-
test
CompletableFuture<WebhookTestResponse> test(String webhookId, WebhookTestParams params, RequestOptions requestOptions)
-
test
CompletableFuture<WebhookTestResponse> test(WebhookTestParams params)
-
test
abstract CompletableFuture<WebhookTestResponse> test(WebhookTestParams params, RequestOptions requestOptions)
-
-
-
-