Class WebhooksServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.async.campaign.WebhooksServiceAsync
public final class WebhooksServiceAsyncImpl implements WebhooksServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhooksServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WebhooksServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WebhooksServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Webhook>create(WebhookCreateParams params, RequestOptions requestOptions)CompletableFuture<Webhook>update(WebhookUpdateParams params, RequestOptions requestOptions)CompletableFuture<WebhookListResponse>list(WebhookListParams params, RequestOptions requestOptions)CompletableFuture<DeleteWebhookResponse>delete(WebhookDeleteParams params, RequestOptions requestOptions)CompletableFuture<WebhookTestResponse>test(WebhookTestParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.async.campaign.WebhooksServiceAsync
create, create, create, delete, delete, delete, list, list, list, list, list, test, test, test, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
WebhooksServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WebhooksServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Webhook> create(WebhookCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Webhook> update(WebhookUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<WebhookListResponse> list(WebhookListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<DeleteWebhookResponse> delete(WebhookDeleteParams params, RequestOptions requestOptions)
-
test
CompletableFuture<WebhookTestResponse> test(WebhookTestParams params, RequestOptions requestOptions)
-
-
-
-