Class InstallationServiceImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.blocking.campaign.InstallationService
public final class InstallationServiceImpl implements InstallationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInstallationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InstallationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InstallationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CampaignInstallationretrieve(InstallationRetrieveParams params, RequestOptions requestOptions)CampaignInstallationupdate(InstallationUpdateParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.blocking.campaign.InstallationService
retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InstallationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InstallationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CampaignInstallation retrieve(InstallationRetrieveParams params, RequestOptions requestOptions)
-
update
CampaignInstallation update(InstallationUpdateParams params, RequestOptions requestOptions)
-
-
-
-