Class InstallationServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.blocking.campaign.InstallationService.WithRawResponse
public final class InstallationServiceImpl.WithRawResponseImpl implements InstallationService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InstallationService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CampaignInstallation>retrieve(InstallationRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<CampaignInstallation>update(InstallationUpdateParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.blocking.campaign.InstallationService.WithRawResponse
retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InstallationService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<CampaignInstallation> retrieve(InstallationRetrieveParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<CampaignInstallation> update(InstallationUpdateParams params, RequestOptions requestOptions)
-
-
-
-