Class OptionsServiceImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.blocking.campaign.OptionsService
public final class OptionsServiceImpl implements OptionsService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOptionsServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OptionsService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OptionsServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CampaignOptionsretrieve(OptionRetrieveParams params, RequestOptions requestOptions)CampaignOptionsupdate(OptionUpdateParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.blocking.campaign.OptionsService
retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
OptionsService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
OptionsService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CampaignOptions retrieve(OptionRetrieveParams params, RequestOptions requestOptions)
-
update
CampaignOptions update(OptionUpdateParams params, RequestOptions requestOptions)
-
-
-
-