Class OptionsServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.blocking.campaign.OptionsService.WithRawResponse
public final class OptionsServiceImpl.WithRawResponseImpl implements OptionsService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description OptionsService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CampaignOptions>retrieve(OptionRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<CampaignOptions>update(OptionUpdateParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.blocking.campaign.OptionsService.WithRawResponse
retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
OptionsService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<CampaignOptions> retrieve(OptionRetrieveParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<CampaignOptions> update(OptionUpdateParams params, RequestOptions requestOptions)
-
-
-
-