Class RewardsServiceImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.blocking.campaign.RewardsService
public final class RewardsServiceImpl implements RewardsService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRewardsServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RewardsService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RewardsServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Rewardcreate(RewardCreateParams params, RequestOptions requestOptions)Rewardupdate(RewardUpdateParams params, RequestOptions requestOptions)CampaignRewardListResponselist(RewardListParams params, RequestOptions requestOptions)DeleteRewardResponsedelete(RewardDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.blocking.campaign.RewardsService
create, create, create, delete, delete, delete, list, list, list, list, list, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
RewardsService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RewardsService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Reward create(RewardCreateParams params, RequestOptions requestOptions)
-
update
Reward update(RewardUpdateParams params, RequestOptions requestOptions)
-
list
CampaignRewardListResponse list(RewardListParams params, RequestOptions requestOptions)
-
delete
DeleteRewardResponse delete(RewardDeleteParams params, RequestOptions requestOptions)
-
-
-
-