Interface WebhooksService
-
- All Implemented Interfaces:
public interface WebhooksServiceProgram webhook configuration (create, update, delete, and test webhooks).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWebhooksService.WithRawResponseA view of WebhooksService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract WebhooksService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WebhooksService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Webhook create(String id, WebhookCreateParams params)
Adds a webhook to the program.
-
create
Webhook create(String id, WebhookCreateParams params, RequestOptions requestOptions)
-
create
Webhook create(WebhookCreateParams params)
-
create
abstract Webhook create(WebhookCreateParams params, RequestOptions requestOptions)
-
update
Webhook update(String webhookId, WebhookUpdateParams params)
Updates a webhook by id.
-
update
Webhook update(String webhookId, WebhookUpdateParams params, RequestOptions requestOptions)
-
update
Webhook update(WebhookUpdateParams params)
-
update
abstract Webhook update(WebhookUpdateParams params, RequestOptions requestOptions)
-
list
WebhookListResponse list(String id)
Lists a program's webhooks (secrets are never returned).
-
list
WebhookListResponse list(String id, WebhookListParams params, RequestOptions requestOptions)
-
list
WebhookListResponse list(String id, WebhookListParams params)
-
list
abstract WebhookListResponse list(WebhookListParams params, RequestOptions requestOptions)
-
list
WebhookListResponse list(WebhookListParams params)
-
list
WebhookListResponse list(String id, RequestOptions requestOptions)
-
delete
DeleteWebhookResponse delete(String webhookId, WebhookDeleteParams params)
Removes a webhook by id.
-
delete
DeleteWebhookResponse delete(String webhookId, WebhookDeleteParams params, RequestOptions requestOptions)
-
delete
DeleteWebhookResponse delete(WebhookDeleteParams params)
-
delete
abstract DeleteWebhookResponse delete(WebhookDeleteParams params, RequestOptions requestOptions)
-
test
WebhookTestResponse test(String webhookId, WebhookTestParams params)
Sends a live test event to a webhook using its stored URL and secret.
-
test
WebhookTestResponse test(String webhookId, WebhookTestParams params, RequestOptions requestOptions)
-
test
WebhookTestResponse test(WebhookTestParams params)
-
test
abstract WebhookTestResponse test(WebhookTestParams params, RequestOptions requestOptions)
-
-
-
-