Class WebhooksServiceImpl
-
- All Implemented Interfaces:
-
com.growsurf.api.services.blocking.campaign.WebhooksService
public final class WebhooksServiceImpl implements WebhooksService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhooksServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WebhooksService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WebhooksServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Webhookcreate(WebhookCreateParams params, RequestOptions requestOptions)Webhookupdate(WebhookUpdateParams params, RequestOptions requestOptions)WebhookListResponselist(WebhookListParams params, RequestOptions requestOptions)DeleteWebhookResponsedelete(WebhookDeleteParams params, RequestOptions requestOptions)WebhookTestResponsetest(WebhookTestParams params, RequestOptions requestOptions)-
Methods inherited from class com.growsurf.api.services.blocking.campaign.WebhooksService
create, create, create, delete, delete, delete, list, list, list, list, list, test, test, test, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
WebhooksService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WebhooksService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Webhook create(WebhookCreateParams params, RequestOptions requestOptions)
-
update
Webhook update(WebhookUpdateParams params, RequestOptions requestOptions)
-
list
WebhookListResponse list(WebhookListParams params, RequestOptions requestOptions)
-
delete
DeleteWebhookResponse delete(WebhookDeleteParams params, RequestOptions requestOptions)
-
test
WebhookTestResponse test(WebhookTestParams params, RequestOptions requestOptions)
-
-
-
-