Interface InstallationServiceAsync
-
- All Implemented Interfaces:
public interface InstallationServiceAsyncProgram Editor Installation tab (
CampaignInstallation) configuration operations.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInstallationServiceAsync.WithRawResponseA view of InstallationServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InstallationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InstallationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<CampaignInstallation> retrieve(String id)
Retrieves a program's Installation configuration.
-
retrieve
CompletableFuture<CampaignInstallation> retrieve(String id, InstallationRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CampaignInstallation> retrieve(String id, InstallationRetrieveParams params)
-
retrieve
abstract CompletableFuture<CampaignInstallation> retrieve(InstallationRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CampaignInstallation> retrieve(InstallationRetrieveParams params)
-
retrieve
CompletableFuture<CampaignInstallation> retrieve(String id, RequestOptions requestOptions)
-
update
CompletableFuture<CampaignInstallation> update(String id, InstallationUpdateParams params)
Updates a program's Installation configuration. Only the fields you send are changed (a surgical merge); omitted fields are left untouched.
-
update
CompletableFuture<CampaignInstallation> update(String id, InstallationUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CampaignInstallation> update(String id)
-
update
CompletableFuture<CampaignInstallation> update(InstallationUpdateParams params)
-
update
abstract CompletableFuture<CampaignInstallation> update(InstallationUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CampaignInstallation> update(String id, RequestOptions requestOptions)
-
-
-
-